@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: commands.c,v 1.57 1999/01/02 22:14:19 kalt Exp $";
+static char rcsid[] = "@(#)$Id: commands.c,v 1.61 1999/01/05 19:25:14 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -19,6 +19,7 @@ static char rcsid[] = "@(#)$Id: commands.c,v 1.57 1999/01/02 22:14:19 kalt Exp $
 #include "option.h"
 #include "term.h"
 #include "utils.h"
+#include "input.h"
 
 extern struct server_ *server;
 
@@ -412,11 +413,11 @@ cmd_alias(p)
 	}
       while (*txt)
 	{
-	  if (*txt == '%' && isdigit(*(txt+1)))
+	  if (*txt == '%' && isdigit((int) *(txt+1)))
 	    {
 	      *wp++ = *txt++; /* % */
 	      *wp++ = '{';
-	      while (isdigit(*txt))
+	      while (isdigit((int) *txt))
 		  *wp++ = *txt++;
 	      *wp++ = '}';
 	    }
@@ -529,8 +530,14 @@ cmd_option(p)
 	  return -4;
       if ((p = index(c, '.')) == NULL)
 	  return -4;
+      c +=1 ;
       *p = '\0';
-      if (map_c2w(++c) == 0)
+      if (c == p)
+	  if (get_channel(NULL))
+	      c = get_channel(NULL)->chname;
+	  else
+	      c = NULL;
+      if (c == NULL || map_c2w(c) == 0)
 	{
 	  vsic_slog(LOG_CLIENT, "%s: No such channel", c);
 	  return 0;
@@ -566,9 +573,9 @@ cmd_option(p)
       flag |= O_ON;
   else if (!strcasecmp(p, "off"))
       flag |= O_OFF;
-  else if (*p == '#' && isdigit(*(p+1)))
+  else if (*p == '#' && isdigit((int) *(p+1)))
       fnum = atoi(p+1) + F_MAX+1;
-  else if (isdigit(*p))
+  else if (isdigit((int) *p))
       fnum = atoi(p);
   else if (*p == 'k' || *p == 'K')
       flag |= O_KEYWORD;
@@ -680,7 +687,7 @@ cmd_option(p)
 	  else if (flag & O_REWRITE)
 	      ui = atoi(c);
 	  else if (str)
-	      while (*str && isspace(*str))
+	      while (*str && isspace((int) *str))
 		  str++;
 	}
       customize(flag, channel, fnum, &str, &ui);
@@ -726,8 +733,12 @@ cmd_window(p)
       sic_chgwin(1);
   else if (!strcasecmp(p, "kill"))
       sic_wkill();
+  else if (!strcasecmp(p, "last"))
+      sic_chgwin(-3);
   else if (!strcasecmp(p, "list"))
       sic_wlist();
+  else if (!strcasecmp(p, "previous"))
+      sic_chgwin(-2);
   else if (!strcasecmp(p, "release"))
       sic_swin(2);
   else if (!strncasecmp(p, "number ", 7))
@@ -789,6 +800,7 @@ struct cmdlist_	cmdlist[] = {
 	{ "QUIT",	cmd_quit},
 	{ "REHASH",	NULL },
 	{ "RESTART",	NULL },
+	{ "RUN",	cmd_run},
 	{ "SEEN",	cmd_seen},
 	{ "SERVER",	cmd_server},
 	{ "SERVLIST",	NULL },
