@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: display.c,v 1.53 1999/01/02 22:14:19 kalt Exp $";
+static char rcsid[] = "@(#)$Id: display.c,v 1.54 1999/01/05 16:57:45 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -26,6 +26,7 @@ extern char		need_collect;
 extern char		tab_add(char *, char *);
 extern char		space_add(char *, char *);
 extern char		sic_ctcp(char *, char, char *);
+extern void		url_find(char *, char *, char *);
 
 static char		outp[1024], outa[1024];
 static char		*s, *c, *d, *p;
@@ -79,7 +80,7 @@ unsigned int	*flags;
 	    {
 	      if (align < 0)
 		  format++;
-	      while (isdigit(*format))
+	      while (isdigit((int) *format))
 		  format++;
 	    }
 
