@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: dns.c,v 1.6 1999/01/02 22:14:19 kalt Exp $";
+static char rcsid[] = "@(#)$Id: dns.c,v 1.7 1999/01/05 16:57:45 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -56,7 +56,7 @@ main()
       if (rc <= 0)
 	  exit(rc);
 
-      if (isdigit(buf[0])) /* incorrect but simple */
+      if (isdigit((int) buf[0])) /* incorrect but simple */
 	{
 	  struct hostent *h;
 	  unsigned long ad;
