@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: format.c,v 1.15 1999/01/02 22:14:19 kalt Exp $";
+static char rcsid[] = "@(#)$Id: format.c,v 1.16 1999/01/05 16:57:45 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -101,7 +101,7 @@ char	*buffer, *attr, *format, *rcpt, *cmd, *param;
             {
               if (align < 0)
                   format++;
-              while (isdigit(*format))
+              while (isdigit((int) *format))
                   format++;
             }
 	  
