@@ -4,4 +4,6 @@
  * See the COPYRIGHT file.
  */
 
+void	display_input();
 int	sic_getch();
+int	cmd_run(char *);
