@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: option.c,v 1.33 1999/01/02 22:14:19 kalt Exp $";
+static char rcsid[] = "@(#)$Id: option.c,v 1.34 1999/01/05 16:57:45 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -524,7 +524,7 @@ get_rewrite(fmt, string, attributes, flags, channel)
 			  else
 			    {
 			      n = atoi(nfmt);
-			      while (isdigit(*nfmt))
+			      while (isdigit((int) *nfmt))
 				  nfmt++;
 			    }
 			  if (n < 20 && (j = pmatch[n].rm_so) != -1)
