@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: server.c,v 1.60 1999/01/02 22:34:19 kalt Exp $";
+static char rcsid[] = "@(#)$Id: server.c,v 1.64 1999/02/26 02:01:33 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -15,16 +15,10 @@ static char rcsid[] = "@(#)$Id: server.c,v 1.60 1999/01/02 22:34:19 kalt Exp $";
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
-#include <signal.h>
 #include <netdb.h>
 #if HAVE_SYS_FILIO_H
 # include <sys/filio.h>
 #endif
-#if HAVE_SYS_IOCTL_H
-# include <sys/ioctl.h>
-#endif
-#include <sys/stat.h>
-#include <fcntl.h>
 
 /* BIND 8.x lossage */
 #undef inet_ntoa
@@ -41,7 +35,7 @@ static char rcsid[] = "@(#)$Id: server.c,v 1.60 1999/01/02 22:34:19 kalt Exp $";
 extern char		need_collect;
 extern struct window_	*current;
 
-extern sic_format(char *, char *, char *, char *);
+extern void sic_format(char *, char *, char *, char *);
 
 static struct server_	*slist = NULL;
 struct server_		*server = NULL;
@@ -236,6 +230,7 @@ dns_parse()
 		    {
 		      vsic_slog(LOG_CLIENT, "--- Connecting to %s %d [%s]",
 				stmp->sname, stmp->port, stmp->ip);
+		      server = stmp;
 		      sic_connect(stmp);
 		    }
 		}
@@ -418,7 +413,7 @@ sic_server(nick, name, port, pass)
   *stmp = server;
 
   server->nick = strdup(nick);
-  if (isdigit(*name))
+  if (isdigit((int) *name))
       server->ip = strdup(name);
   server->sname = strdup(name);
   server->port = port;
@@ -609,7 +604,7 @@ sic_select()
   char		buf[10240];
 
   FD_ZERO(&rfd); FD_ZERO(&wfd); FD_ZERO(&efd);
-  timeout.tv_usec = 0; timeout.tv_sec = 45;
+  timeout.tv_usec = 0; timeout.tv_sec = 5;
 
   FD_SET(0, &rfd);
   while (stmp)
@@ -673,6 +668,9 @@ sic_select()
   term_flush();
   n = select(255, &rfd, &wfd, NULL, &timeout);
 
+  if (n < 0)
+      return 0;
+
   stmp = slist;
   while (stmp)
     {
@@ -813,10 +811,10 @@ sic_select()
 		    }
 		  if (option(stmp->sopt, S_DCC) && stmp->pass)
 		    { /* file transfer */
-		      if (stmp->readf == NULL)
+		      if (stmp->readf == 0)
 			  stmp->readf = open(stmp->pass,
 					     O_WRONLY|O_TRUNC|O_CREAT, 0644);
-		      if (stmp->readf == NULL)
+		      if (stmp->readf == 0)
 			{
 			  vsic_slog(LOG_CLIENT,
 				    "--- Unable to create file \"%s\"!",
@@ -1021,7 +1019,7 @@ cmd_server(p)
 	}
     }
   else
-      if (isdigit(*p) && !index(p, '.'))
+      if (isdigit((int) *p) && !index(p, '.'))
 	{
 	  if (current->via && (option(current->via->sopt, S_CONNECTED)
 			       || option(current->via->sopt, S_CONNECTING)))
