@@ -1,7 +1,7 @@
 /*
  * 
  *
- * Copyright(c) 1997,1998 - All Rights Reserved
+ * Copyright(c) 1997,1998,1999 - All Rights Reserved
  *
  * See the COPYRIGHT file.
  */
@@ -26,6 +26,7 @@ enum /* boolean options */
   Z_HOLD,	/* ircii like holdmode: don't automatically scroll */
   Z_VCOUNT,	/* verbose counters: underlines the static part of the match */
   Z_VCTCP,	/* verbose CTCPs */
+  Z_URL,	/* grab URLs */
   ZMAX
 };
 
@@ -224,7 +225,7 @@ struct server_
   int			fd;
   char			readbuf[520];
   unsigned long		size, read, sent;	/* DCC file size */
-  FILE			*readf; /* incoming file */
+  int			readf; /* incoming file */
   int			sendf; /* outgoing file */
   unsigned char		sopt[(SMAX + 7)/8];
 
