@@ -7,190 +7,165 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: term.c,v 1.15 1999/01/02 22:14:20 kalt Exp $";
+static char rcsid[] = "@(#)$Id: term.c,v 1.20 1999/02/26 00:08:52 kalt Exp $";
 #endif
 
 #include "os.h"
 
 #include "term.h"
 
-int		tty_fd;
+static	struct termios oldt, newt;
+static	int mytty;
 
-int	LI, CO, SG		/* number of garbage chars left by so or se */;
+int	LI,			/* number of lines */
+	CO;			/* number of columns */
 char    *CM,			/* screen-relative cursor motion */
+	*ND,			/* non destructive space (cursor right) */
+	*LE,			/* move cursor left one position */
+
 	*CE,			/* clear to end of line */
 	*CL,			/* clear screen and home cursor */
-	*CR,			/* carriage return character */
-	*NL,			/* newline character */
-#ifdef NEED_ALTERNATE_SCOLL_FUNCTION
-	*AL,			/* add 1 blank line (al), n blank lines (AL) */
-	*DL,			/* delete line (dl) or n lines (DL) */
-#endif
-	*CS,			/* change scrolling region (vt100) */
-	*DC,			/* delete character */
-	*IC,			/* insert character */
-#ifdef NEED_ALTERNATE_INSERT_CHARACTER
-	*IM, *EI,		/* insert mode & end insert mode */
-#endif
+	*DC,			/* delete character */ /* UNUSED */
+	*IC,			/* insert character */ /* UNUSED */
+
 	*SO, *SE,		/* begin and end standout mode */
 	*US, *UE,		/* start and end underscore mode */
 	*MD,			/* turn on extra bright (bold) */
-#ifdef UGLY
-	*MB, *MH,		/* turn on blink, half bright attribute */
-#endif
 	*ME,			/* turn off all attributes */
+
+	*CS,			/* change scrolling region (vt100) */
 	*SF,			/* scroll text up */
+	*NL,			/* newline character */
 	*SR,			/* scroll text down */
-	*ND,			/* non destructive space (cursor right) */
-	*LE,			/* move cursor left one position */
+
 	*BL;			/* bell */
 
 /*
  * terminal initialization
- *	read termcap, and uses few curses commands
+ *	read termcap, setup the terminal the way we want it to be..
  */
 void
 term_init()
 {
-/*  char	bp[1024], area[1024], *term;*/
-  char area[1024], *ptr;
+  char	termcap[1024], area[1024], *term, *ptr;
 
-  /* this makes getch() fail on systems where it is a macro for wgetch() */
-  delwin(initscr());
-  cbreak();
-  noecho();
+  int i = 0, missing = 0;
+  char *cap_name[] = { "cm", "nd", "le", "ce", "cl", "dc", "ic", "so", "se", "us", "ue", "md", "me", "cs", "sf", "nl", "sr", "bl", 0 };
+  char **cap_var[] = { &CM, &ND, &LE, &CE, &CL, &DC, &IC, &SO, &SE, &US, &UE, &MD, &ME, &CS, &SF, &NL, &SR, &BL };
 
-  ptr=area;
-
-/* tgetent() screws up the terminal, I don't know why..
-   things look find without it, so let's drop it.
+  /* Open the tty.  Using it might not be necessary, but won't hurt */
+  mytty = open("/dev/tty", O_RDWR, 0);
+  if (mytty < 0)
+    {
+      perror("Unable to open /dev/tty");
+      exit(1);
+    }
+  /* Get all the info we need from the termcap entry */
   if ((term = getenv("TERM")) == NULL)
     {
       fprintf(stderr, "TERM variable is not set!\n");
       exit(1);
     }
-  if (tgetent(bp, term) < 1)
+  if (tgetent(termcap, term) < 1)
     {
       fprintf(stderr, "No TERMCAP entry for ``%s''.\n", term);
       exit(1);
     }
-*/
-  if ((CO = tgetnum("co")) == -1)
-      CO = 80;
-  if ((LI = tgetnum("li")) == -1)
-      LI = 24;
-#ifdef TTERM
-  /*printf("TERM=%s CO=%d LI=%d", term, CO, LI);*/
-#endif
-  SG = tgetnum("sg");
-  CM = (char *) tgetstr("cm", &ptr);
-  CL = (char *) tgetstr("cl", &ptr);
-  if (CM == NULL || CL == NULL)
-    {
-      fprintf(stderr,
-	      "This terminal does not have the necessary capabilities.\n");
-      exit(1);
-    }
-  if ((CR = (char *) tgetstr("cr", &ptr)) == NULL)
-      CR = "\r";
-  if ((NL = (char *) tgetstr("nl", &ptr)) == NULL)
-      NL = "\n";
-  CE = (char *) tgetstr("ce", &ptr);
-#ifdef TTERM
-  if (CE == NULL)
-      fprintf(stderr, "ce is undefined for this terminal. (critical)\n");
-#endif
-  ND = (char *) tgetstr("nd", &ptr);
-#ifdef TTERM
-  if (ND == NULL)
-      fprintf(stderr, "nd is undefined for this terminal.\n");
-#endif
-  LE = (char *) tgetstr("le", &ptr);
-#ifdef TTERM
-  if (LE == NULL)
-    {
-      fprintf(stderr, "le is undefined for this terminal.\n");
-      if (tgetstr("bs", &ptr))
-	  fprintf(stderr, "\tcould be emulated using ``bs''.\n");
-    }
-#endif
-  SF = (char *) tgetstr("sf", &ptr);
-#ifdef TTERM
-  if (SF == NULL)
-      fprintf(stderr,
-	      "sf is undefined for this terminal.\n");
-#endif
-  SR = (char *) tgetstr("sr", &ptr);
-#ifdef TTERM
-  if (SR == NULL)
-      fprintf(stderr, "sr is undefined for this terminal. (critical)\n");
-#endif
-  CS = (char *) tgetstr("cs", &ptr);
-#ifdef TTERM
-  if (CS == NULL)
-      fprintf(stderr, "cs is undefined for this terminal. (critical)\n");
-#endif
-  IC = (char *) tgetstr("ic", &ptr);
-#ifdef TTERM
-  if (IC == NULL)
-    {
-      fprintf(stderr, "ic is undefined for this terminal.\n");
-      if (tgetstr("im", &ptr) && tgetstr("ei", (char **) &area))
-	  fprintf(stderr, "\tcould be emulated using ``em'' and ``ei''.\n");
-    }
-#endif
-  DC = (char *) tgetstr("dc", &ptr);
-#ifdef TTERM
-  if (DC == NULL)
-      fprintf(stderr, "dc is undefined for this terminal.\n");
-#endif
 
-  SO = (char *) tgetstr("so", &ptr);
-  SE = (char *) tgetstr("se", &ptr);
-  if (SO == NULL || SE == NULL)
+  ptr = area;
+
+  if ((CO = tgetnum("co")) == -1) CO = 80;
+  if ((LI = tgetnum("li")) == -1) LI = 24;
+
+  while (cap_name[i])
     {
-      SO = "";
-      SE = "";
-#ifdef TTERM
-      fprintf(stderr, "``so'' or ``se'' undefined\n");
-#endif
+      *(cap_var[i]) = (char *) tgetstr(cap_name[i], &ptr);
+      if (strcmp(cap_name[i], "nl") && strcmp(cap_name[i], "bl")
+	  && *(cap_var[i]) == NULL)
+	{
+	  missing += 1;
+	  fprintf(stderr, "%s is undefined for this terminal.\n", cap_name[i]);
+	}
+      i += 1;
     }
-  US = (char *) tgetstr("us", &ptr);
-  UE = (char *) tgetstr("ue", &ptr);
-  if (US == NULL || UE == NULL)
+  if (NL == NULL) NL = "\n";
+  if (BL == NULL) BL = "\007";
+  if (IC == NULL) missing -= 1; /* unused */
+  if (DC == NULL) missing -= 1; /* unused */
+  if (missing)
     {
-      US = "";
-      UE = "";
-#ifdef TTERM
-      fprintf(stderr, "``so'' or ``se'' undefined\n");
-#endif
-    }
-  MD = (char *) tgetstr("md", &ptr);
-  ME = (char *) tgetstr("me", &ptr);
-  if (MD == NULL || ME == NULL)
-    {
-      MD = "";
-      ME = "";
-#ifdef TTERM
-      fprintf(stderr, "``mb'' or ``me'' undefined. (bold unavailable)\n");
-#endif
-    }
-  if ((BL = (char *) tgetstr("bl", &ptr)) == (char *) 0)
-    {
-      BL = "\007";
-#ifdef TTERM
-      fprintf(stderr, "``bl'' undefined\n");
-#endif
+      fprintf(stderr, "Things will probably not work well, but might be easy to fix.\n");
+      sleep(2);
     }
 
-  term_clear();
+  if (SO == NULL || SE == NULL) { SO = ""; SE = ""; }
+  if (US == NULL || UE == NULL) { US = ""; UE = ""; }
+  if (MD == NULL || ME == NULL) { MD = ""; ME = ""; }
+
+  /* let's try to avoid silly crashes */
+  i = -1;
+  while (cap_name[++i])
+      if (*(cap_var[i]) == NULL)
+	  *(cap_var[i]) = "";
+  
+  tcgetattr(mytty, &oldt);		/* save the tty settings */
+
+  newt = oldt;
+  newt.c_lflag &= ~(ICANON | ECHO);	/* cbreak() noecho() */
+  newt.c_cc[VMIN] = 1;			/* read() returns if >= 1 char */
+  newt.c_cc[VTIME] = 0;			/* no timer on read() */
+
+  tcsetattr(mytty, TCSADRAIN, &newt);	/* setup tty the way we like it */
+  term_size();				/* try to get the size, really */
+
+  term_clear();				/* clear the screen */
+}
+
+/* terminal reinitialization */
+void
+term_reinit()
+{
+  tcsetattr(mytty, TCSADRAIN, &newt);
+}
+
+/* term_size: try to get the terminal size
+ *	returns 0 if same as before
+ *	returns 1 if changed
+ *	returns -1 if ioctl() failed.
+ *	returns -2 if no TIOCGWINSZ to get size
+ */
+int
+term_size()
+{
+#if defined(TIOCGWINSZ)
+  struct winsize ws;
+  int nLI = LI, nCO = CO, ret = 0;
+
+  if (ioctl(mytty, TIOCGWINSZ, &ws) < 0)
+      return -1;
+  if (ws.ws_row)
+      nLI = ws.ws_row;
+  if (ws.ws_col)
+      nCO = ws.ws_col;
+  if (LI != nLI || CO != nCO)
+      ret = 1;
+  LI = nLI; CO = nCO;
+  return ret;
+#else
+  return -2;
+#endif
 }
 
 /* restore the terminal to what it was before */
 void
 term_end()
 {
-  endwin();
+  term_move_cursor(0, LI-1);		/* last line */
+  term_clreol();			/* clear it */
+  sic_tputs(tgoto(CS, LI-1, 0));	/* reset scrolling region */
+  term_move_cursor(0, LI-1);		/* go to last line again */
+  tcsetattr(mytty, TCSADRAIN, &oldt);	/* reset tty settings */
+  fflush(stdout);
 }
 
 /* display a character on the screen.
@@ -367,7 +342,7 @@ term_input(str, pos)
   char	*str;
   int	pos;
 {
-  static	c = 0;
+  static int c = 0;
 
   if (str)
     {
@@ -378,35 +353,3 @@ term_input(str, pos)
     }
   term_move_cursor(c, LI-1);
 }
-
-#ifdef TTERM
-void
-main()
-{
-  unsigned int i = 0;
-
-  printf("Checking term.c in test mode\n");
-  term_init();
-
-  sleep(10);
-  term_puts("normal", 6);  term_standout_on();  term_puts(" reverse ", 9);
-  term_bold_on();  term_puts(" r+b ", 5);  term_standout_off();
-  term_puts(" bold ", 6);  term_bold_off();  term_nl();
-
-  term_puts("esc: del: blah:", 18);  term_nl();
-  term_flush();
-/*
-  sleep(1);
-  term_scroll(1, 3, 3);
-  term_flush();
-  sleep(2);
-  term_scroll(10, 15, -2);
-  term_flush();
-  sleep(2);
-*/
-  
-  term_end();
-
-  exit(0);
-}
-#endif
