@@ -26,8 +26,6 @@ extern	char	*CM,
 		*DO,
 		*CE,
 		*CL,
-		*CR,
-		*NL,
 		*SO,
 		*SE,
 		*US,
@@ -36,12 +34,12 @@ extern	char	*CM,
 		*ME,
 		*BL;
 extern	int	CO,
-		LI,
-		SG;
-
+		LI;
 
 /* real functions */
 void		term_init();
+void		term_reinit();
+int		term_size();
 void		term_end();
 void		term_putchar(unsigned int);
 int		term_puts(char *, int);
@@ -57,8 +55,6 @@ void		term_input(char *, int);
 #define term_clear()		(sic_tputs(CL))
 #define term_clreol()		(sic_tputs(CE));
 #define term_move_cursor(c, r)	(sic_tputs(tgoto(CM, (c), (r))))
-#define term_cr()		(sic_tputs(CR))
-#define term_nl()		(sic_tputs(NL))
 #define term_beep()		(sic_tputs(BL), fflush(stdout))
 #define term_underline_on()	(sic_tputs(US))
 #define term_underline_off()	(sic_tputs(UE))
