@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: url.c,v 1.2 1999/01/02 22:14:20 kalt Exp $";
+static char rcsid[] = "@(#)$Id: url.c,v 1.3 1999/01/05 16:57:45 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -42,8 +42,8 @@ char *sender, *target, *text;
       if (lf == NULL)
 	  return;
 
-      while (url > text && isalpha(*(url-1))) url -= 1;
-      while (*end && !isspace(*end)) end += 1;
+      while (url > text && isalpha((int) *(url-1))) url -= 1;
+      while (*end && !isspace((int) *end)) end += 1;
       bk = *end;
       *end = '\0';
       vsic_slog(LOG_DEBUG, "Logging URL: %s", url);
