@@ -7,7 +7,7 @@
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: window.c,v 1.59 1999/01/02 22:14:20 kalt Exp $";
+static char rcsid[] = "@(#)$Id: window.c,v 1.63 1999/01/08 17:20:00 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -26,7 +26,7 @@ void		vsic_log(unsigned int, char *, char *, char *,
 void		sic_redowin(int);
 void		collect_channel();
 
-extern sic_reformat(struct log_ *);
+extern void	sic_reformat(struct log_ *);
 extern struct server_	*server;
 
 char	need_collect = 0;
@@ -329,8 +329,16 @@ cmd_seen(p)
 	  if (hit)
 	    {
 	      for (i = 0; i < hit; i++)
-		  if (!strcasecmp(found[i]->origin, ltmp->origin))
-		      break;
+		{
+		  if (strcasecmp(found[i]->origin, ltmp->origin))
+		    continue;
+		  if (found[i]->dest == NULL && ltmp->dest == NULL)
+		    continue;
+		  if (found[i]->dest == NULL || ltmp->dest == NULL)
+		    break;
+		  if (!strcasecmp(found[i]->dest, ltmp->dest))
+		    break;
+		}
 	    }
 	  if (i == hit)
 	    {
@@ -1194,7 +1202,7 @@ char *name;
     {
       if (option(ctmp->copt, C_JOINING) && *ctmp->chname == '!')
 	{
-	  if (ctmp->chname[1] == '#')
+	  if (ctmp->chname[1] == '#' || ctmp->chname[1] == '!')
 	      sname = ctmp->chname+1;
 	  else
 	      sname = ctmp->chname;
@@ -1219,7 +1227,7 @@ void
 new_channel(name)
 char *name;
 {
-  struct channel_ *new;
+  struct channel_ *new, *save;
 
   assert (map_c2w(name) == 0);
   new = (struct channel_ *) malloc(sizeof(struct channel_));
@@ -1231,9 +1239,12 @@ char *name;
   new->on->via = server;
   /*bzero(new->copt, sizeof(new->copt));*/
   new->chname = strdup(name);
+  save = current->defchan;
+  current->defchan = new; /* so that cmd_option gets the right channel name */
+  cfg_read(name);
+  current->defchan = save;
   if (!current->defchan)
       current->defchan = new;
-  cfg_read(name);
 }
 
 /* join_channel: try to join a channel */
